// Code appropriated and cobbled together by Scott Brown, 17 October, 2009
//
// Data capture based on Storing Mouse Data sketch in Processing handbook (Reas and Fry) p.307
//
// OSC and the Wiimote, using OSCulator based on oscReceiveWiiIR by Andreas Schlegel, andi@sojamo.de
//
// DMX from proDMX library SendData sketch

// Import libraries
import oscP5.*;
import netP5.*;
import codeanticode.prodmx.*;
import processing.serial.*;
import timeline.*;

// Set variable names
OscP5 osc;
DMX dmx;
PFont font;
Timeline timeline;

// For drawing Wiimote/nunchuck coords - 3 sets
float[] wiiPitchDraw_01;
float[] wiiRollDraw_01;
float[] wiiYawDraw_01;
float[] wiiAccelDraw_01;
float[] nunPitchDraw_01;
float[] nunRollDraw_01;
float[] nunYawDraw_01;
float[] nunAccelDraw_01;

float[] wiiPitchDraw_02;
float[] wiiRollDraw_02;
float[] wiiYawDraw_02;
float[] wiiAccelDraw_02;
float[] nunPitchDraw_02;
float[] nunRollDraw_02;
float[] nunYawDraw_02;
float[] nunAccelDraw_02;

void setup() {
  // Set the size of the window
  size(screen.width/4, 800);
  frameRate(25);
  
  // Open an up port for listening to incoming osc messages from OSCulator
  osc = new OscP5(this,"localhost",9000);
  
  // Plug in 3 sets of Wiimote/nunchuck from OSCulator
  osc.plug(this,"wiiPry_01","/wii/1/accel/pry");
  osc.plug(this,"nunPry_01","/wii/1/nunchuk/accel/pry");
  
  osc.plug(this,"wiiPry_02","/wii/2/accel/pry");
  osc.plug(this,"nunPry_02","/wii/2/nunchuk/accel/pry");
  
  // Connect to timeline data
  timeline = new Timeline(this);
  
  // Setting up DMX connection
  String portName = Serial.list()[0];
  dmx = new DMX(this, portName, 115200, 32);
  
  // Set the visual characteristics of the window
  background(255);
  smooth();
  noFill();
  
  // For writing labels on Wiimote data
  font = loadFont("Helvetica-18.vlw");
  textFont(font);
  
  // Drawing Wii values - 2 sets
  wiiPitchDraw_01 = new float[width];
  wiiRollDraw_01 = new float[width];
  wiiYawDraw_01 = new float[width];
  wiiAccelDraw_01 = new float[width];
  nunPitchDraw_01 = new float[width];
  nunRollDraw_01 = new float[width];
  nunYawDraw_01 = new float[width];
  nunAccelDraw_01 = new float[width];
  
  wiiPitchDraw_02 = new float[width];
  wiiRollDraw_02 = new float[width];
  wiiYawDraw_02 = new float[width];
  wiiAccelDraw_02 = new float[width];
  nunPitchDraw_02 = new float[width];
  nunRollDraw_02 = new float[width];
  nunYawDraw_02 = new float[width];
  nunAccelDraw_02 = new float[width];
}

// Setup variables for importing Wiimote data via OSCulator
float wiiPitch_01;
float wiiRoll_01;
float wiiYaw_01;
float wiiAccel_01;
float nunPitch_01;
float nunRoll_01;
float nunYaw_01;
float nunAccel_01;

float wiiPitch_02;
float wiiRoll_02;
float wiiYaw_02;
float wiiAccel_02;
float nunPitch_02;
float nunRoll_02;
float nunYaw_02;
float nunAccel_02;

// Get Wiimote data from OSCulator
void wiiPry_01(float _wiiPitch_01, float _wiiRoll_01, float _wiiYaw_01, float _wiiAccel_01) {
  wiiPitch_01 = _wiiPitch_01;
  wiiRoll_01 = _wiiRoll_01;
  wiiYaw_01 = _wiiYaw_01;
  wiiAccel_01 = _wiiAccel_01;
}

void nunPry_01(float _nunPitch_01, float _nunRoll_01, float _nunYaw_01, float _nunAccel_01) {
  nunPitch_01 = _nunPitch_01;
  nunRoll_01 = _nunRoll_01;
  nunYaw_01 = _nunYaw_01;
  nunAccel_01 = _nunAccel_01;
}

void wiiPry_02(float _wiiPitch_02, float _wiiRoll_02, float _wiiYaw_02, float _wiiAccel_02) {
  wiiPitch_02 = _wiiPitch_02;
  wiiRoll_02 = _wiiRoll_02;
  wiiYaw_02 = _wiiYaw_02;
  wiiAccel_02 = _wiiAccel_02;
}

void nunPry_02(float _nunPitch_02, float _nunRoll_02, float _nunYaw_02, float _nunAccel_02) {
  nunPitch_02 = _nunPitch_02;
  nunRoll_02 = _nunRoll_02;
  nunYaw_02 = _nunYaw_02;
  nunAccel_02 = _nunAccel_02;
}

// Lights
float lightFront_fill = 0.0;
float lightLeft_fill = 0.0;
float lightRight_fill = 0.0;
float lightBack_fill = 0.0;

// To move through light sequences
int sequenceCount = 1;

void draw() {
  noStroke();
  
  // Background rows
  fill(229);
  rect(0, 0, width, height/8);
  fill(216);
  rect(0, height/8, width, height/4);
  fill(229);
  rect(0, height/4, width, height/2-height/8);
  fill(216);
  rect(0, height/2-height/8, width, height/2);
  fill(229);
  rect(0, height/2, width, height/2+height/8);
  fill(216);
  rect(0, height/2+height/8, width, height-height/4);
  fill(229);
  rect(0, height-height/4, width, height-height/8);
  fill(216);
  rect(0, height-height/8, width, height);
  
  // Labels
  fill(100);
  text("Nunchuck Pitch", 10, height/8-10);
  text("Nunchuck Roll", 10, height/4-10);
  text("Nunchuck Yaw", 10, height/2-height/8-10);
  text("Nunchuck Accel", 10, height/2-10);
  text("Wiimote Pitch", 10, height/2+height/8-10);
  text("Wiimote Roll", 10, height-height/4-10);
  text("Wiimote Yaw", 10, height-height/8-10);
  text("Wiimote Accel", 10, height-10);
  
  // Drawing Wii data movement...
  
  // Wiimote 01
  stroke(222, 47, 20);
  
  for (int i = wiiPitchDraw_01.length-1; i > 0; i--) {
    wiiPitchDraw_01[i] = wiiPitchDraw_01[i-1];
  }
  wiiPitchDraw_01[0] = map(wiiPitch_01, 0.0, 1.0, height/2+height/8, height/2);
  for(int i = 1; i < wiiPitchDraw_01.length; i++) {
    line(i, wiiPitchDraw_01[i], i-1, wiiPitchDraw_01[i-1]);
  }
  
  for (int i = wiiRollDraw_01.length-1; i > 0; i--) {
    wiiRollDraw_01[i] = wiiRollDraw_01[i-1];
  }
  wiiRollDraw_01[0] = map(wiiRoll_01, 0.0, 1.0, height-height/4, height/2+height/8);
  for(int i = 1; i < wiiRollDraw_01.length; i++) {
    line(i, wiiRollDraw_01[i], i-1, wiiRollDraw_01[i-1]);
  }
  
  for (int i = wiiYawDraw_01.length-1; i > 0; i--) {
    wiiYawDraw_01[i] = wiiYawDraw_01[i-1];
  }
  wiiYawDraw_01[0] = map(wiiYaw_01, 0.0, 1.0, height-height/8, height-height/4);
  for(int i = 1; i < wiiYawDraw_01.length; i++) {
    line(i, wiiYawDraw_01[i], i-1, wiiYawDraw_01[i-1]);
  }
  
  for (int i = wiiAccelDraw_01.length-1; i > 0; i--) {
    wiiAccelDraw_01[i] = wiiAccelDraw_01[i-1];
  }
  wiiAccelDraw_01[0] = map(wiiAccel_01, 0.0, 1.0, height, height-height/8);
  for(int i = 1; i < wiiAccelDraw_01.length; i++) {
    line(i, wiiAccelDraw_01[i], i-1, wiiAccelDraw_01[i-1]);
  }
  
  // Nunchuck 01
  stroke(222, 47, 20);

  for (int i = nunPitchDraw_01.length-1; i > 0; i--) {
    nunPitchDraw_01[i] = nunPitchDraw_01[i-1];
  }
  nunPitchDraw_01[0] = map(nunPitch_01, 0.0, 1.0, height/8, 0.0);
  for(int i = 1; i < nunPitchDraw_01.length; i++) {
    line(i, nunPitchDraw_01[i], i-1, nunPitchDraw_01[i-1]);
  }
  
  for (int i = nunRollDraw_01.length-1; i > 0; i--) {
    nunRollDraw_01[i] = nunRollDraw_01[i-1];
  }
  nunRollDraw_01[0] = map(nunRoll_01, 0.0, 1.0, height/4, height/8);
  for(int i = 1; i < nunRollDraw_01.length; i++) {
    line(i, nunRollDraw_01[i], i-1, nunRollDraw_01[i-1]);
  }
  
  for (int i = nunYawDraw_01.length-1; i > 0; i--) {
    nunYawDraw_01[i] = nunYawDraw_01[i-1];
  }
  nunYawDraw_01[0] = map(nunYaw_01, 0.0, 1.0, height/2-height/8, height/4);
  for(int i = 1; i < nunYawDraw_01.length; i++) {
    line(i, nunYawDraw_01[i], i-1, nunYawDraw_01[i-1]);
  }
  
  for (int i = nunAccelDraw_01.length-1; i > 0; i--) {
    nunAccelDraw_01[i] = nunAccelDraw_01[i-1];
  }
  nunAccelDraw_01[0] = map(nunAccel_01, 0.0, 1.0, height/2, height/2-height/8);
  for(int i = 1; i < nunAccelDraw_01.length; i++) {
    line(i, nunAccelDraw_01[i], i-1, nunAccelDraw_01[i-1]);
  }
  
  // Wiimote 02
  stroke(35, 180, 16);
  
  for (int i = wiiPitchDraw_02.length-1; i > 0; i--) {
    wiiPitchDraw_02[i] = wiiPitchDraw_02[i-1];
  }
  wiiPitchDraw_02[0] = map(wiiPitch_02, 0.0, 1.0, height/2+height/8, height/2);
  for(int i = 1; i < wiiPitchDraw_02.length; i++) {
    line(i, wiiPitchDraw_02[i], i-1, wiiPitchDraw_02[i-1]);
  }
  
  for (int i = wiiRollDraw_02.length-1; i > 0; i--) {
    wiiRollDraw_02[i] = wiiRollDraw_02[i-1];
  }
  wiiRollDraw_02[0] = map(wiiRoll_02, 0.0, 1.0, height-height/4, height/2+height/8);
  for(int i = 1; i < wiiRollDraw_02.length; i++) {
    line(i, wiiRollDraw_02[i], i-1, wiiRollDraw_02[i-1]);
  }
  
  for (int i = wiiYawDraw_02.length-1; i > 0; i--) {
    wiiYawDraw_02[i] = wiiYawDraw_02[i-1];
  }
  wiiYawDraw_02[0] = map(wiiYaw_02, 0.0, 1.0, height-height/8, height-height/4);
  for(int i = 1; i < wiiYawDraw_02.length; i++) {
    line(i, wiiYawDraw_02[i], i-1, wiiYawDraw_02[i-1]);
  }
  
  for (int i = wiiAccelDraw_02.length-1; i > 0; i--) {
    wiiAccelDraw_02[i] = wiiAccelDraw_02[i-1];
  }
  wiiAccelDraw_02[0] = map(wiiAccel_02, 0.0, 1.0, height, height-height/8);
  for(int i = 1; i < wiiAccelDraw_02.length; i++) {
    line(i, wiiAccelDraw_02[i], i-1, wiiAccelDraw_02[i-1]);
  }
  
  // Nunchuck 02
  stroke(35, 180, 16);

  for (int i = nunPitchDraw_02.length-1; i > 0; i--) {
    nunPitchDraw_02[i] = nunPitchDraw_02[i-1];
  }
  nunPitchDraw_02[0] = map(nunPitch_02, 0.0, 1.0, height/8, 0.0);
  for(int i = 1; i < nunPitchDraw_02.length; i++) {
    line(i, nunPitchDraw_02[i], i-1, nunPitchDraw_02[i-1]);
  }
  
  for (int i = nunRollDraw_02.length-1; i > 0; i--) {
    nunRollDraw_02[i] = nunRollDraw_02[i-1];
  }
  nunRollDraw_02[0] = map(nunRoll_02, 0.0, 1.0, height/4, height/8);
  for(int i = 1; i < nunRollDraw_02.length; i++) {
    line(i, nunRollDraw_02[i], i-1, nunRollDraw_02[i-1]);
  }
  
  for (int i = nunYawDraw_02.length-1; i > 0; i--) {
    nunYawDraw_02[i] = nunYawDraw_02[i-1];
  }
  nunYawDraw_02[0] = map(nunYaw_02, 0.0, 1.0, height/2-height/8, height/4);
  for(int i = 1; i < nunYawDraw_02.length; i++) {
    line(i, nunYawDraw_02[i], i-1, nunYawDraw_02[i-1]);
  }
  
  for (int i = nunAccelDraw_02.length-1; i > 0; i--) {
    nunAccelDraw_02[i] = nunAccelDraw_02[i-1];
  }
  nunAccelDraw_02[0] = map(nunAccel_02, 0.0, 1.0, height/2, height/2-height/8);
  for(int i = 1; i < nunAccelDraw_02.length; i++) {
    line(i, nunAccelDraw_02[i], i-1, nunAccelDraw_02[i-1]);
  }
  
  // Stage
  fill(216);
  rect(width-200, height-800, 200, height);
  fill(0);
  rect(width-200, height-200, 200, 200);
  fill(100);
  text("Stage", width-190, height-210);
  
  // Lights
  stroke(255);
  // Front
  fill(lightFront_fill);
  ellipse(width-120, height-20, 15, 15);
  ellipse(width-80, height-20, 15, 15);
  // Left
  fill(lightLeft_fill);
  ellipse(width-180, height-100, 15, 15);
  // Right
  fill(lightRight_fill);
  ellipse(width-20, height-100, 15, 15);
  // Back
  fill(lightBack_fill);
  rect(width-150, height-180, 100, 25);
  
  // DMX business...
  
  // lightFront = DMXChannel0
  // lightLeft = DMXChannel1
  // lightRight = DMXChannel2
  // lightBack = DMXChannel3
  
  // DMX stopped until OSC data from both Wiimotes begins
  if(wiiRoll_01 != 0.0 && wiiYaw_01 != 0.0 && wiiRoll_02 != 0.0 && wiiYaw_02 != 0.0) {
    
    // 1. Fade up lightBack 12sec
    if(sequenceCount == 1) {
      println(sequenceCount);
      if(lightBack_fill < 200.0) {
        lightBack_fill = lightBack_fill + 0.5;
        dmx.setDMXChannel(3, (int)(lightBack_fill));
      }
      if(lightBack_fill == 200.0) {
        sequenceCount = sequenceCount + 1;
      }
    }
      
    // 2. Nunchuks control lightLeft and lightRight
    if(sequenceCount == 2) {
      println(sequenceCount);
      if(lightBack_fill == 200.0) {
        lightLeft_fill = map(nunPitch_02, 0.0, 1.0, 0, 200);
        lightRight_fill = map(nunPitch_01, 0.0, 1.0, 0, 200);
        dmx.setDMXChannel(1, (int)(lightLeft_fill));
        dmx.setDMXChannel(2, (int)(lightRight_fill));
      }
      if(lightLeft_fill > 170 && lightRight_fill > 170) {
        sequenceCount = sequenceCount + 1;
      }
    }
        
    // 3. Fade out lightBack and lightLeft/lightRight and fade in lightFront
    if(sequenceCount == 3) {
      println(sequenceCount);
      if(lightBack_fill > 0.0) {
        lightBack_fill = lightBack_fill - 2.0;
        dmx.setDMXChannel(3, (int)(lightBack_fill));
      }
      if(lightFront_fill < 250.0) {
        lightFront_fill = lightFront_fill + 2.0;
        dmx.setDMXChannel(0, (int)(lightFront_fill));
      }
      if(lightLeft_fill > 0.0) {
        lightLeft_fill = lightLeft_fill - 2.0;
        dmx.setDMXChannel(1, (int)(lightLeft_fill));
      }
      if(lightRight_fill > 0.0) {
        lightRight_fill = lightRight_fill - 2.0;
        dmx.setDMXChannel(2, (int)(lightRight_fill));
      }
      if(nunPitch_01 < 0.2 && nunPitch_02 < 0.2) {
        sequenceCount = sequenceCount + 1;
      }
    }
    
    // 4. Fade up lightBack when facing each other
    if(sequenceCount == 4) {
      println(sequenceCount);
      if(sequenceCount == 4 && lightBack_fill < 175.0) {
        lightBack_fill = lightBack_fill + 1.0;
        dmx.setDMXChannel(3, (int)(lightBack_fill));
      }
      if(nunPitch_01 < 0.4 && nunPitch_02 > 0.6) {
        sequenceCount = sequenceCount + 1;
      }
    }
    
    // 5. lightLeft up for Andrew reaching up
    if(sequenceCount == 5) {
      println(sequenceCount);
      if(sequenceCount == 5) {
        lightLeft_fill = map(nunPitch_01, 0.0, 1.0, 0, 200);
        dmx.setDMXChannel(1, (int)(lightLeft_fill));
      }
      if(wiiPitch_02 > 0.75) {
        sequenceCount = sequenceCount + 1;
      }
    }
    
    // 6. lightBack down and lightLeft/lightRight up
    if(sequenceCount == 6) {
      println(sequenceCount);
      if(lightBack_fill > 0.0) {
        lightBack_fill = lightBack_fill - 1.0;
        dmx.setDMXChannel(3, (int)(lightBack_fill));
      }
      if(lightLeft_fill < 100.0) {
        lightLeft_fill = lightLeft_fill + 2.0;
        dmx.setDMXChannel(1, (int)(lightLeft_fill));
      }
      if(lightLeft_fill >= 100.0) {
        lightLeft_fill = map(wiiPitch_02, 0.0, 1.0, 0, 200);
        dmx.setDMXChannel(1, (int)(lightLeft_fill));
      }
      if(lightRight_fill < 100.0) {
        lightRight_fill = lightRight_fill + 2.0;
        dmx.setDMXChannel(2, (int)(lightRight_fill));
      }
      if(lightRight_fill >= 100.0) {
        lightRight_fill = map(wiiPitch_02, 0.0, 1.0, 0, 200);
        dmx.setDMXChannel(2, (int)(lightRight_fill));
      }
      if(nunPitch_01 < 0.35 && wiiPitch_01 < 0.35 && nunPitch_02 < 0.35 && wiiPitch_02 < 0.35) {
        sequenceCount = sequenceCount + 1;
      }
    }
    
    // 7. lightBack top brightness and lightLeft/lightRight accel effected
    if(sequenceCount == 7) {
      println(sequenceCount);
      if(lightFront_fill > 0.0) {
        lightFront_fill = lightFront_fill - 3.0;
        dmx.setDMXChannel(0, (int)(lightFront_fill));
      }
      if(lightBack_fill < 150.0) {
        lightBack_fill = lightBack_fill + 3.0;
        dmx.setDMXChannel(3, (int)(lightBack_fill));
      }
      if(lightBack_fill > 125.0) {
        lightFront_fill = map(nunAccel_02, 0.0, 1.0, 100, 200);
        dmx.setDMXChannel(0, (int)(lightFront_fill));
        lightRight_fill = map(nunAccel_01, 0.0, 1.0, 100, 200);
        dmx.setDMXChannel(2, (int)(lightRight_fill));
        lightLeft_fill = map(nunAccel_01, 0.0, 1.0, 100, 200);
        dmx.setDMXChannel(1, (int)(lightLeft_fill));
      }
      if(wiiPitch_01 < 0.3 && nunPitch_01 < 0.4 && wiiAccel_01 < 0.25 && nunAccel_01 < 0.25 && wiiPitch_02 < 0.3 && nunPitch_02 < 0.4 && wiiAccel_02 < 0.25 && nunAccel_02 < 0.25) {
        sequenceCount = sequenceCount + 1;
      }
    }
    
    // 8. Repeat 4. with Andrew light control
    if(sequenceCount == 8) {
      println(sequenceCount);
      if(lightFront_fill > 0.0) {
        lightFront_fill = lightFront_fill - 1.0;
        dmx.setDMXChannel(0, (int)(lightFront_fill));
      }
      if(lightLeft_fill > 0.0) {
        lightLeft_fill = lightLeft_fill - 1.0;
        dmx.setDMXChannel(1, (int)(lightLeft_fill));
      }
      if(lightRight_fill > 0.0) {
        lightRight_fill = lightRight_fill - 1.0;
        dmx.setDMXChannel(2, (int)(lightRight_fill));
      }
      if(lightBack_fill > 175.0) {
        lightBack_fill = lightBack_fill - 0.5;
        dmx.setDMXChannel(3, (int)(lightBack_fill));
      }
      if(lightBack_fill < 175.0) {
        lightBack_fill = lightBack_fill + 0.5;
        dmx.setDMXChannel(3, (int)(lightBack_fill));
      }
      if(lightRight_fill < 1.0) {
        lightRight_fill = map(nunPitch_01, 0.0, 1.0, 50, 250);
        dmx.setDMXChannel(2, (int)(lightRight_fill));
      }
      if(wiiPitch_01 > 0.5) {
        sequenceCount = sequenceCount + 1;
      }
    }
    
    // 9. Andrew wiiPitch frontLight control
    if(sequenceCount == 9) {
      println(sequenceCount);
      if(lightRight_fill > 0.0) {
        lightRight_fill = lightRight_fill - 0.5;
        dmx.setDMXChannel(2, (int)(lightRight_fill));
      }
      if(lightBack_fill > 0.0) {
        lightBack_fill = lightBack_fill - 0.5;
        dmx.setDMXChannel(3, (int)(lightBack_fill));
      }
      if(sequenceCount == 9) {
        lightFront_fill = map(wiiPitch_01, 0.0, 1.0, 50, 150);
        dmx.setDMXChannel(0, (int)(lightFront_fill));
      }
      if(wiiPitch_01 < 0.3) {
        sequenceCount = sequenceCount + 1;
      }
    }
    
    // 10. Fade out front, up sides and back
    if(sequenceCount == 10) {
      println(sequenceCount);
      if(lightFront_fill > 0.0) {
        lightFront_fill = lightFront_fill - 0.5;
        dmx.setDMXChannel(0, (int)(lightFront_fill));
      }
      if(lightBack_fill < 175.0) {
        lightBack_fill = lightBack_fill + 1.0;
        dmx.setDMXChannel(3, (int)(lightBack_fill));
      }
      if(lightBack_fill == 175.0) {
        lightLeft_fill = map(nunPitch_02, 0.0, 1.0, 50, 200);
        dmx.setDMXChannel(1, (int)(lightLeft_fill));
        lightRight_fill = map(nunPitch_02, 0.0, 1.0, 50, 200);
        dmx.setDMXChannel(2, (int)(lightRight_fill));
      }
      if(wiiPitch_01 < 0.3 && wiiAccel_01 < 0.3 && nunPitch_01 > 0.25 && nunAccel_01 < 0.3 && wiiPitch_02 < 0.3 && wiiAccel_02 < 0.3 && nunPitch_02 > 0.25 && nunAccel_02 < 0.3) {
        sequenceCount = sequenceCount + 1;
      }
    }
    
    // 11. Fade out all
    if(sequenceCount == 11) {
      println(sequenceCount);
      if(lightBack_fill > 0.0) {
        lightBack_fill = lightBack_fill - 0.5;
        dmx.setDMXChannel(0, (int)(lightBack_fill));
      }
      if(lightLeft_fill > 0.0) {
        lightLeft_fill = lightLeft_fill - 0.5;
        dmx.setDMXChannel(1, (int)(lightLeft_fill));
      }
      if(lightRight_fill > 0.0) {
        lightRight_fill = lightRight_fill - 0.5;
        dmx.setDMXChannel(2, (int)(lightRight_fill));
      }
    }
  }
}

// In case of lighting emergency, press keys...
void keyReleased() {
  if(key == '=') {
    sequenceCount = sequenceCount + 1;
  }
  if(key == '-') {
    sequenceCount = sequenceCount - 1;
  }
  if(key =='0') {
    lightLeft_fill = 0.0;
    dmx.setDMXChannel(1, (int)(lightLeft_fill));
    lightRight_fill = 0.0;
    dmx.setDMXChannel(2, (int)(lightRight_fill));
  }
}

// Reset on exit
void stop() {
  // Shutdown DMX lights
  dmx.setDMXChannel(0, (int)(0));
  dmx.setDMXChannel(1, (int)(0));
  dmx.setDMXChannel(2, (int)(0));
  dmx.setDMXChannel(3, (int)(0));
  
  // Reset timeline to origin
  timeline.setTime("lightFront_timeline", 0.0);
  timeline.setTime("lightLeft_timeline", 0.0);
  timeline.setTime("lightRight_timeline", 0.0);
  timeline.setTime("lightBack_timeline", 0.0);
  
  super.stop();
}
